@@ -10,7 +10,8 @@ _console: Optional["Console"] = None
 
 
 def get_console() -> "Console":
-    """Get a global Console instance.
+    """Get a global :class:`~rich.console.Console` instance. This function is used when Rich requires a Console,
+    and hasn't been explicitly given one.
 
     Returns:
         Console: A console instance.
@@ -31,6 +32,16 @@ def print(
     file: IO[str] = None,
     flush: bool = False,
 ):
+    """Print object(s) supplied via positional arguments. This function has an identical signature
+    to the built-in print. For more advanced features, see the :class:`~rich.console.Console` class.
+
+    Args:
+        sep (str, optional): Separator between printed objects. Defaults to " ".
+        end (str, optional): Character to write at end of output. Defaults to "\n".
+        file (IO[str], optional): File to write to, or None for stdout. Defaults to None.
+        flush (bool, optional): Has no effect as Rich always flushes output.. Defaults to False.
+
+    """
     from .console import Console
 
     write_console = get_console() if file is None else Console(file=file)
