@@ -473,12 +473,11 @@ class Text(JupyterMixin):
     def set_length(self, new_length: int) -> None:
         """Set new length of the text, clipping or padding is required."""
         length = len(self)
-        if length == new_length:
-            return
-        if length < new_length:
-            self.pad_right(new_length - length)
-        else:
-            self.plain = self.plain[:new_length]
+        if length != new_length:
+            if length < new_length:
+                self.pad_right(new_length - length)
+            else:
+                self.plain = self.plain[:new_length]
 
     def __rich_console__(
         self, console: "Console", options: "ConsoleOptions"
@@ -522,7 +521,7 @@ class Text(JupyterMixin):
         """
 
         text = self.plain
-        null_style = Style.empty()
+        null_style = Style.null()
         enumerated_spans = list(enumerate(self._spans, 1))
         get_style = partial(console.get_style, default=null_style)
         style_map = {index: get_style(span.style) for index, span in enumerated_spans}
